@@ -22,6 +22,10 @@ NULL
 #' line from the edge startpoint pointing north, and the straight line from
 #' the edge startpoint and the edge endpoint. Calculated with
 #' \code{\link[lwgeom]{st_geod_azimuth}}. Requires a geographic CRS.
+#'
+#' @param degrees Should the angle be returned in degrees instead of radians?
+#' Defaults to \code{FALSE}.
+#'
 #' @examples
 #' library(sf, quietly = TRUE)
 #' library(tidygraph, quietly = TRUE)
@@ -32,14 +36,21 @@ NULL
 #'   activate("edges") %>%
 #'   mutate(azimuth = edge_azimuth())
 #'
+#' net %>%
+#'   activate("edges") %>%
+#'   mutate(azimuth = edge_azimuth(degrees = TRUE))
+#'
 #' @importFrom lwgeom st_geod_azimuth
 #' @importFrom tidygraph .G
+#' @importFrom units set_units
 #' @export
-edge_azimuth = function() {
+edge_azimuth = function(degrees = FALSE) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
   bounds = edge_boundary_nodes(x)
-  st_geod_azimuth(bounds)[seq(1, length(bounds), 2)]
+  values = st_geod_azimuth(bounds)[seq(1, length(bounds), 2)]
+  if (degrees) values = set_units(values, "degrees")
+  values
 }
 
 #' @describeIn spatial_edge_measures The ratio of the length of an edge
@@ -60,17 +71,14 @@ edge_azimuth = function() {
 #' @importFrom units drop_units
 #' @export
 edge_circuity = function(Inf_as_NaN = FALSE) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
   # Calculate circuity.
-  values = st_length(edge_geom(x)) / straight_line_distance(x)
+  values = st_length(pull_edge_geom(x)) / straight_line_distance(x)
+  # Drop units since circuity is unitless (it is a ratio of m/m).
+  if (inherits(values, "units")) values = drop_units(values)
   # Replace Inf values by NaN if requested.
-  if (Inf_as_NaN) {
-    # Units need to be dropped to run comparison '== Inf'.
-    raw_values = if (inherits(values, "units")) drop_units(values) else values
-    inf_values = raw_values == Inf
-    values[inf_values] = NaN
-  }
+  if (Inf_as_NaN) values[is.infinite(values)] = NaN
   values
 }
 
@@ -85,9 +93,10 @@ edge_circuity = function(Inf_as_NaN = FALSE) {
 #' @importFrom tidygraph .G
 #' @export
 edge_length = function() {
+  require_active_edges()
   x = .G()
-  if (has_spatially_explicit_edges(x)) {
-    st_length(edge_geom(x))
+  if (has_explicit_edges(x)) {
+    st_length(pull_edge_geom(x))
   } else {
     straight_line_distance(x)
   }
@@ -103,6 +112,7 @@ edge_length = function() {
 #' @importFrom tidygraph .G
 #' @export
 edge_displacement = function() {
+  require_active_edges()
   x = .G()
   straight_line_distance(x)
 }
@@ -110,12 +120,12 @@ edge_displacement = function() {
 #' @importFrom sf st_distance
 straight_line_distance = function(x) {
   # Extract the nodes from the network.
-  nodes = node_geom(x)
+  nodes = pull_node_geom(x)
   # Get the indices of the boundary nodes of each edge.
   # Returns a matrix with source ids in column 1 and target ids in column 2.
   idxs = edge_boundary_node_indices(x, matrix = TRUE)
   # Calculate distances pairwise.
-  diag(st_distance(nodes[idxs[, 1]], nodes[idxs[, 2]]))
+  st_distance(nodes[idxs[, 1]], nodes[idxs[, 2]], by_element = TRUE)
 }
 
 #' Query edges with spatial predicates
@@ -193,106 +203,106 @@ NULL
 #' @importFrom sf st_intersects
 #' @export
 edge_intersects = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_intersects(edge_geom(x), y, ...)) > 0
+  lengths(st_intersects(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_disjoint
 #' @export
 edge_is_disjoint = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_disjoint(edge_geom(x), y, ...)) > 0
+  lengths(st_disjoint(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_touches
 #' @export
 edge_touches = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_touches(edge_geom(x), y, ...)) > 0
+  lengths(st_touches(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_crosses
 #' @export
 edge_crosses = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_crosses(edge_geom(x), y, ...)) > 0
+  lengths(st_crosses(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_within
 #' @export
 edge_is_within = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_within(edge_geom(x), y, ...)) > 0
+  lengths(st_within(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_contains
 #' @export
 edge_contains = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_contains(edge_geom(x), y, ...)) > 0
+  lengths(st_contains(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_contains_properly
 #' @export
 edge_contains_properly = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_contains_properly(edge_geom(x), y, ...)) > 0
+  lengths(st_contains_properly(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_overlaps
 #' @export
 edge_overlaps = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_overlaps(edge_geom(x), y, ...)) > 0
+  lengths(st_overlaps(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_equals
 #' @export
 edge_equals = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_equals(edge_geom(x), y, ...)) > 0
+  lengths(st_equals(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_covers
 #' @export
 edge_covers = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_covers(edge_geom(x), y, ...)) > 0
+  lengths(st_covers(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_covered_by
 #' @export
 edge_is_covered_by = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_covered_by(edge_geom(x), y, ...)) > 0
+  lengths(st_covered_by(pull_edge_geom(x), y, ...)) > 0
 }
 
 #' @name spatial_edge_predicates
 #' @importFrom sf st_is_within_distance
 #' @export
 edge_is_within_distance = function(y, ...) {
+  require_active_edges()
   x = .G()
-  require_spatially_explicit_edges(x)
-  lengths(st_is_within_distance(edge_geom(x), y, ...)) > 0
+  lengths(st_is_within_distance(pull_edge_geom(x), y, ...)) > 0
 }
